@@ -6,7 +6,7 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Any, TypeVar, cast
 
 from tox.config.loader.api import ConfigLoadArgs, Loader, Override
-from tox.config.loader.replacer import replace
+from tox.config.loader.replacer import MatchError, replace
 from tox.config.set_env import SetEnv
 from tox.config.types import Command, EnvList
 from tox.report import HandledError
@@ -62,7 +62,7 @@ class TomlLoader(Loader[TomlTypes]):
 
     def build(  # noqa: PLR0913
         self,
-        key: str,  # noqa: ARG002
+        key: str,
         of_type: type[_T] | UnionType,
         factory: Factory[_T],
         conf: Config | None,
@@ -70,9 +70,16 @@ class TomlLoader(Loader[TomlTypes]):
         args: ConfigLoadArgs,
     ) -> _T:
         delay_replace = inspect.isclass(of_type) and issubclass(of_type, SetEnv)
-        unroll = Unroll(conf=conf, loader=self, args=args)
-        exploded = unroll(raw, skip_str=True) if delay_replace else unroll(raw)
-        result = self.to(exploded, of_type, factory)
+        try:
+            unroll = Unroll(conf=conf, loader=self, args=args)
+            exploded = unroll(raw, skip_str=True) if delay_replace else unroll(raw)
+            result = self.to(exploded, of_type, factory)
+        except (HandledError, MatchError):
+            raise
+        except Exception as exception:
+            name = "core" if args.env_name is None else args.env_name
+            msg = f"failed to load {name}.{key}: {exception}"
+            raise HandledError(msg) from exception
         if delay_replace:
             loader = self
 
